<?php
/**
 * Jamroom 5 Automatic User Link module
 *
 * copyright 2003 - 2014
 * by The Jamroom Network
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0.  Please see the included "license.html" file.
 *
 * This module may include works that are not developed by
 * The Jamroom Network
 * and are used under license - any licenses are included and
 * can be found in the "contrib" directory within this module.
 *
 * Jamroom may use modules and skins that are licensed by third party
 * developers, and licensed under a different license  - please
 * reference the individual module or skin license that is included
 * with your installation.
 *
 * This software is provided "as is" and any express or implied
 * warranties, including, but not limited to, the implied warranties
 * of merchantability and fitness for a particular purpose are
 * disclaimed.  In no event shall the Jamroom Network be liable for
 * any direct, indirect, incidental, special, exemplary or
 * consequential damages (including but not limited to, procurement
 * of substitute goods or services; loss of use, data or profits;
 * or business interruption) however caused and on any theory of
 * liability, whether in contract, strict liability, or tort
 * (including negligence or otherwise) arising from the use of this
 * software, even if advised of the possibility of such damage.
 * Some jurisdictions may not allow disclaimers of implied warranties
 * and certain statements in the above disclaimer may not apply to
 * you as regards implied warranties; the other terms and conditions
 * remain enforceable notwithstanding. In some jurisdictions it is
 * not permitted to limit liability and therefore such limitations
 * may not apply to you.
 *
 * @copyright 2012 Talldude Networks, LLC.
 */

// make sure we are not being called directly
defined('APP_DIR') or exit();

/**
 * jrLinkProfile_meta
 */
function jrLinkProfile_meta()
{
    $_tmp = array(
        'name'        => 'Automatic User Link',
        'url'         => 'linkprofile',
        'version'     => '1.0.0',
        'developer'   => 'The Jamroom Network, &copy;'. strftime('%Y'),
        'description' => 'Automatically Links User Account(s) to newly created profiles',
        'category'    => 'users',
        'license'     => 'mpl'
    );
    return $_tmp;
}

/**
 * jrLinkProfile_init
 */
function jrLinkProfile_init()
{
    // db_create_item listener
    jrCore_register_event_listener('jrCore', 'db_create_item', 'jrLinkProfile_db_create_item_listener');
    return true;
}

//--------------------------------------
// EVENT LISTENERS
//--------------------------------------

/**
 * Add User ID to Profile ID
 * Prevent comments on private groups from being shown outside profile owners/admins
 * @param $_data array Array of information from trigger
 * @param $_user array Current user
 * @param $_conf array Global Config
 * @param $_args array additional parameters passed in by trigger caller
 * @param $event string Triggered Event name
 * @return array
 */
function jrLinkProfile_db_create_item_listener($_data, $_user, $_conf, $_args, $event)
{
    if (isset($_args['module']) && $_args['module'] == 'jrProfile' && isset($_conf['jrLinkProfile_user_ids']) && strlen($_conf['jrLinkProfile_user_ids']) > 0) {
        $_us = explode(',', $_conf['jrLinkProfile_user_ids']);
        if ($_us && is_array($_us)) {
            // See if we are doing specific quota_ids.
            $_qt = false;
            if (isset($_conf['jrLinkProfile_quota_ids']) && strlen($_conf['jrLinkProfile_quota_ids']) > 0) {
                $_qi = explode(',', $_conf['jrLinkProfile_quota_ids']);
                if ($_qi && is_array($_qi)) {
                    foreach ($_qi as $k => $qid) {
                        $qid = (int) $qid;
                        $_qt[$qid] = 1;
                    }
                }
                unset($_qi);
            }
            foreach ($_us as $uid) {
                $uid = (int) trim($uid);
                if (!$_qt || isset($_qt["{$_data['profile_quota_id']}"])) {
                    jrProfile_create_user_link($_args['_item_id'], $uid);
                }
            }
        }
    }
    return $_data;
}
